@@ -1,5 +1,5 @@
 /* Handle so called `shell archives'.
-   Copyright (C) 1994, 1995, 1996, 2002 Free Software Foundation, Inc.
+   Copyright (C) 1994, 1995, 1996, 2002, 2005 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -435,7 +435,7 @@ warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n\
           if (arg == NULL)
             break;
 
-          sz = strlen (current_directory) + strlen (argv[optind]) + 2;
+          sz = strlen (current_directory) + strlen (arg) + 2;
           if (sz > buflen)
             {
               buflen = sz + 32;
